This function solves a quadratic programming problem using the Differential Evolution optimization method from the DEoptim package.
qp_solver_DEoptim(
n,
A,
b,
c,
x_max = 1,
print_message = FALSE,
NP = 100,
itermax = 100,
...
)A list containing:
The optimal objective function value.
The optimal values of the decision variables.
An integer representing the number of decision variables.
A matrix representing the quadratic coefficients.
A numeric vector representing the linear coefficients.
A numeric scalar representing the constant term in the objective function.
An integer representing the upper bound for the decision variables. Default is 1.
A logical value indicating whether to print optimization details. Default is FALSE.
An integer specifying the population size for the DEoptim algorithm. Default is 50.
An integer specifying the maximum number of iterations. Default is 100.
Additional control parameters for DEoptim.
qp_solver, qp_solver_GA, qp_solver_nloptr