This function solves a quadratic programming problem using the Sequential Least Squares Programming (SLSQP) algorithm from the nloptr package.
qp_solver_nloptr(
n,
A,
b,
c,
x_max = 1,
print_message = FALSE,
xtol_rel = 1e-08,
maxeval = 10000,
print_level = 0,
...
)A list containing:
The optimal objective function value.
The optimal values of the decision variables.
An integer representing the number of decision variables.
A matrix representing the quadratic coefficients.
A numeric vector representing the linear coefficients.
A numeric scalar representing the constant term in the objective function.
An integer representing the upper bound for the decision variables. Default is 1.
A logical value indicating whether to print optimization details. Default is FALSE.
A numeric value specifying the relative tolerance for convergence. Default is 1e-8.
An integer specifying the maximum number of function evaluations. Default is 10000.
An integer controlling the verbosity of output. Default is 0.
Additional control parameters for nloptr.
qp_solver, qp_solver_DEoptim, qp_solver_GA